# SpaMint
The software implementation of the method in 
[Deciphering more accurate cell-cell interactions by modeling cells and their interactions]().

<img src="https://github.com/deepomicslab/SpexMod/raw/main/main.jpg" alt="SpaMint-Main">

# Pre-requirements
* numpy, pandas==1.5.2
* scipy
* scanpy
* loess
* umap
  

# Installation

# Usage

